rm(list = ls())

library(DTA)
library(tidyverse)

# upload Pombe normalized count table with samples, where thiouracil was added
countTable = read.csv("data/RNA_count_tables/countCerevisiae_genes_minusStranded__ThiouracilYESonly_pombeNormalized.csv") %>% 
  column_to_rownames(var = "X")

# load metadata and filter out the samples where thiouracil was not added
metadata = read.csv("data/metadata.csv") %>% 
  filter(added_4sU == "+") %>% 
  dplyr::rename(name = sampleNames) %>% 
  mutate(time = 6) 
rownames(metadata) = metadata$name
metadata$nr = rep(c(1,2,3,4), 3)

# make sure the samples are in the same order
countTable = countTable[, rownames(metadata)]

# there cannot be any zero counts in the matrix - let's filter those genes out
zeroSum = rowSums(countTable == 0)
zeroSum = zeroSum[zeroSum == 0]

countTable_nonZero = countTable[names(zeroSum),]

# create list of reliable genes - all genes left
# reformat metadata and count table to fit the DTA function
reliable_DTA = rownames(countTable_nonZero)
metadata_DTA = as.matrix(metadata)
countTable_DTA = as.matrix(countTable_nonZero)


# use method bias to estimate LtoT ratio
res_DTA = DTA.estimate(phenomat = metadata_DTA,
                       datamat = countTable_DTA,
                       tnumber = Sc.tnumber, 
                       check = T,
                       ccl = 150,
                       mRNAs = 60000,
                       reliable = reliable_DTA, folder = "data/figures",
                       condition = "real_data",save.plots = TRUE,notinR = TRUE, 
                       ratiomethod = "bias")

resList = res_DTA$`6`

# extract gene names and synthesis rates (divide by 150 to make the result
# per minute not per cell cycle)
synthesis = resList$sr / 150
genes = names(synthesis)

# create final table with synthesis rates - these need to be divided by 
resTable = data.frame(gene = genes, synthesis)
#write.csv(resTable, paste0("data/DTA_results.csv"))
